@@ -1,4 +1,4 @@
-/*  Copyright (C) 2018 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2020 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -11,8 +11,9 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
+
 /*!
  * \file
  *
@@ -375,7 +376,7 @@ typedef enum {
 typedef enum {
 	KNOTD_QUERY_FLAG_NO_AXFR    = 1 << 0, /*!< Don't process AXFR. */
 	KNOTD_QUERY_FLAG_NO_IXFR    = 1 << 1, /*!< Don't process IXFR. */
-	KNOTD_QUERY_FLAG_LIMIT_ANY  = 1 << 2, /*!< Limit ANY QTYPE (respond with TC=1). */
+	KNOTD_QUERY_FLAG_LIMIT_ANY  = 1 << 2, /*!< Limit ANY QTYPE (respond with just one RRSet). */
 	KNOTD_QUERY_FLAG_LIMIT_SIZE = 1 << 3, /*!< Apply UDP size limit. */
 	KNOTD_QUERY_FLAG_COOKIE     = 1 << 4, /*!< Valid DNS Cookie indication. */
 } knotd_query_flag_t;
@@ -399,7 +400,7 @@ typedef struct {
 	knot_rrset_t opt_rr;            /*!< OPT record. */
 	knot_sign_context_t sign;       /*!< Signing context. */
 	knot_edns_client_subnet_t *ecs; /*!< EDNS Client Subnet option. */
-	bool err_truncated;             /*!< Set TC bit if error reply. */
+	bool err_truncated;             /*!< Set TC and AA bits if an error reply. */
 
 	/*! Persistent items on processing reset. */
 	knot_mm_t *mm;                /*!< Memory context. */
@@ -526,6 +527,13 @@ int knotd_mod_dnssec_init(knotd_mod_t *mod);
  */
 int knotd_mod_dnssec_load_keyset(knotd_mod_t *mod, bool verbose);
 
+/*!
+ * Frees up resources before re-loading DNSSEC signing keys.
+ *
+ * \param[in] mod  Module context.
+ */
+void knotd_mod_dnssec_unload_keyset(knotd_mod_t *mod);
+
 /*!
  * Generates RRSIGs for given RRSet.
  *
